@@ -286,8 +286,8 @@ class StickProtocol():
             partyId = data['partyId']
         else:  # Sharing to the currentUser's party (currentUsers' profile)
             membersIds = connections_ids
-            isSelf = data['type'] == 'self'
-            partyId = Party.objects.get(user=user, self=isSelf).id
+            isIndividual = data['type'] == 'individual'
+            partyId = Party.objects.get(user=user, individual=isIndividual).id
         dict = {}
         bundlesToFetch = []
         responseDict = {}
@@ -478,3 +478,28 @@ class StickProtocol():
             return {"bundle": bundle, "verify": True}
         else:
             return {"verify": False}
+
+
+    def process_reencrypted_keys(self, data, user):
+        success = False
+        if user.check_password(data['currentPass']):
+            for key in data['preKeys']:
+                preKey = PreKey.objects.get(keyId=key['id'], user=user)
+                preKey.cipher = key['cipher']
+                preKey.salt = key['salt']
+                preKey.save()
+            for key in data['signedPreKeys']:
+                spk = SignedPreKey.objects.get(keyId=key['id'], user=user)
+                spk.cipher = key['cipher']
+                spk.salt = key['salt']
+                spk.save()
+            for key in data['identityKeys']:
+                ik = IdentityKey.objects.get(keyId=key['id'], user=user)
+                ik.cipher = key['cipher']
+                ik.salt = key['salt']
+                ik.save()
+            user.passwordSalt = data["newSalt"]
+            user.set_password(data["newPass"])
+            user.save()
+            success = True
+        return {"success": success}
